@@ -40,9 +40,10 @@ class PageAdmin(MPTTModelAdmin):
             'classes': ('content',)
         }),
         ('Other Stuff', {
-            'fields': ('slug',
-                        'order',
-                        'password',),
+            'fields': ( 'layout',
+                        'password',
+                        'slug',
+                        'order',),
             'classes': ('collapse', 'other')
         })
     )
