@@ -2,6 +2,7 @@ import hashlib
 from django import forms
 from mptt.forms import TreeNodeChoiceField
 from mptt.admin import MPTTAdminForm
+from writingfield import FullScreenTextarea
 from ccpages.models import Page
 
 
@@ -9,7 +10,9 @@ class PageAdminForm(MPTTAdminForm):
 
     class Meta:
         model = Page
-
+        widgets = {
+            'content': FullScreenTextarea()
+        }
     class Media:
         css = {
                 'screen': ('ccpages/css/admin.css',)
