@@ -15,6 +15,16 @@ CCPAGES_IMAGE_SIZES = getattr(
             (480,320),
             (960,640)))
 
+CCPAGES_LAYOUTS = (
+    ('ccpages/view.html', 'default'),
+)
+try:
+    CCPAGES_LAYOUTS += settings.CCPAGES_LAYOUTS
+except AttributeError:
+    pass
+
+
+
 """Path to the custom layouts"""
 try:
     layouts = settings.TEMPLATE_DIRS[0] + 'ccpages/layouts/'
